summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorChris Phan <cphan@us.ibm.com>2014-09-03 10:09:30 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2014-09-08 15:14:47 -0500
commit64a4cc44eec52438c34e0f718b3901e2e2b2a7bf (patch)
tree0510c17d42b6a6b746d4848c69c1d41ca3f2e033 /src
parentb26546f59175cb2c94c2646ab104a2257b676a34 (diff)
downloadblackbird-hostboot-64a4cc44eec52438c34e0f718b3901e2e2b2a7bf.tar.gz
blackbird-hostboot-64a4cc44eec52438c34e0f718b3901e2e2b2a7bf.zip
PRD: fix last functional core termination issue
Change-Id: Ie6dce55f38c954fead1593af478bf92dce1d6c18 CQ: SW275619 Backport: release-fips811 Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/13118 Tested-by: Jenkins Server Reviewed-by: Prem Shanker Jha <premjha2@in.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com> Reviewed-by: Zane Shelley <zshelle@us.ibm.com> Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/13165
Diffstat (limited to 'src')
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/service/prdfTargetServices.C20
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/service/prdfTargetServices.H12
2 files changed, 16 insertions, 16 deletions
diff --git a/src/usr/diag/prdf/common/framework/service/prdfTargetServices.C b/src/usr/diag/prdf/common/framework/service/prdfTargetServices.C
index 72d428f96..fc8eea822 100755
--- a/src/usr/diag/prdf/common/framework/service/prdfTargetServices.C
+++ b/src/usr/diag/prdf/common/framework/service/prdfTargetServices.C
@@ -5,7 +5,9 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* COPYRIGHT International Business Machines Corp. 2012,2014 */
+/* Contributors Listed Below - COPYRIGHT 2012,2014 */
+/* [+] International Business Machines Corp. */
+/* */
/* */
/* Licensed under the Apache License, Version 2.0 (the "License"); */
/* you may not use this file except in compliance with the License. */
@@ -855,19 +857,15 @@ TARGETING::TargetHandleList getFunctionalTargetList( TARGETING::TYPE i_type )
//------------------------------------------------------------------------------
-// FIXME: In the past, this was a wrapper for a GARD interface. Need to make
-// sure that we have the equivelant functionality.
-bool checkLastFuncCore( TARGETING::TargetHandle_t i_coreTarget )
+bool checkLastFuncEx( TARGETING::TargetHandle_t i_exTarget )
{
- bool o_lastCore = false;
-
- // TODO: Possibly support TYPE_EX, TYPE_L2, and TYPE_L3 as target input.
+ bool o_lastEx = false;
- TargetHandleList l_list = getFunctionalTargetList( TYPE_CORE );
- if ( 1 == l_list.size() && l_list[0] == i_coreTarget )
- o_lastCore = true;
+ TargetHandleList l_list = getFunctionalTargetList( TYPE_EX );
+ if ( 1 == l_list.size() && l_list[0] == i_exTarget )
+ o_lastEx = true;
- return o_lastCore;
+ return o_lastEx;
}
//##############################################################################
diff --git a/src/usr/diag/prdf/common/framework/service/prdfTargetServices.H b/src/usr/diag/prdf/common/framework/service/prdfTargetServices.H
index 142c67927..cbb965b8e 100755
--- a/src/usr/diag/prdf/common/framework/service/prdfTargetServices.H
+++ b/src/usr/diag/prdf/common/framework/service/prdfTargetServices.H
@@ -5,7 +5,9 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* COPYRIGHT International Business Machines Corp. 2012,2014 */
+/* Contributors Listed Below - COPYRIGHT 2012,2014 */
+/* [+] International Business Machines Corp. */
+/* */
/* */
/* Licensed under the Apache License, Version 2.0 (the "License"); */
/* you may not use this file except in compliance with the License. */
@@ -230,11 +232,11 @@ TARGETING::TargetHandle_t getParentChip( TARGETING::TargetHandle_t i_target );
TARGETING::TargetHandleList getFunctionalTargetList( TARGETING::TYPE i_type );
/**
* @brief Determines if the given target is the last functional core.
* @param i_coreTarget A core target.
* @return TRUE if target is last functional core, FALSE otherwise.
*/
-bool checkLastFuncCore( TARGETING::TargetHandle_t i_coreTarget );
+bool checkLastFuncEx( TARGETING::TargetHandle_t i_exTarget );
//##############################################################################
//##
OpenPOWER on IntegriCloud
@@ -230,11 +232,11 @@ TARGETING::TargetHandle_t getParentChip( TARGETING::TargetHandle_t i_target );
TARGETING::TargetHandleList getFunctionalTargetList( TARGETING::TYPE i_type );
/**
- * @brief Determines if the given target is the last functional core.
- * @param i_coreTarget A core target.
- * @return TRUE if target is last functional core, FALSE otherwise.
+ * @brief Determines if the given target is the last functional EX.
+ * @param i_exTarget A EX target.
+ * @return TRUE if target is last functional EX, FALSE otherwise.
*/